<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('delivery');

// 记录访问日志
record_log('访问配送任务创建页面');

// 初始化提示信息
$error = null;
$success = null;

// 处理单个订单创建配送任务
if (isset($_GET['order_id'])) {
    $order_id = intval($_GET['order_id']);

    // 查询订单信息
    $stmt = $pdo->prepare("
        SELECT o.*, m.name as member_name, m.phone as member_phone, m.address as member_address
        FROM orders o 
        LEFT JOIN members m ON o.member_id = m.id
        WHERE o.id = ? AND o.status = 3
    ");
    $stmt->execute([$order_id]);
    $order = $stmt->fetch();

    if ($order) {
        // 检查是否已存在配送任务
        $stmt = $pdo->prepare("SELECT id FROM delivery_tasks WHERE order_id = ?");
        $stmt->execute([$order_id]);

        if ($stmt->rowCount() > 0) {
            $error = "订单 #{$order['order_no']} 已存在配送任务，不能重复创建";
        } else {
            // 获取收货地址
            $delivery_address = $order['member_address'] ?: '未设置地址';

            // 设置预计送达时间（当前时间+2小时）
            $expected_time = date('Y-m-d H:i:s', strtotime('+2 hours'));

            // 创建配送任务
            $stmt = $pdo->prepare("
                INSERT INTO delivery_tasks (
                    order_id, delivery_type, expected_time, 
                    route_info, status, create_time, update_time
                ) VALUES (
                    ?, 1, ?, ?, 1, NOW(), NOW()
                )
            ");

            $result = $stmt->execute([
                $order_id,
                $expected_time,
                $delivery_address
            ]);

            if ($result) {
                record_log("为订单 #{$order['order_no']} 创建了配送任务");
                $success = "为订单 {$order['order_no']} 创建配送任务成功";
            } else {
                $error = "配送任务创建失败，请重试";
            }
        }
    } else {
        $error = "订单不存在或状态不是待配送";
    }
}

// 处理批量创建配送任务
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['create_tasks']) && !empty($_POST['order_ids'])) {
    $created_count = 0;
    $failed_count = 0;

    $pdo->beginTransaction();

    try {
        foreach ($_POST['order_ids'] as $order_id) {
            // 查询订单信息
            $stmt = $pdo->prepare("
                SELECT o.*, m.name as member_name, m.phone as member_phone, m.address as member_address
                FROM orders o 
                LEFT JOIN members m ON o.member_id = m.id
                WHERE o.id = ? AND o.status = 3
            ");
            $stmt->execute([intval($order_id)]);
            $order = $stmt->fetch();

            if ($order) {
                // 检查是否已存在配送任务
                $stmt = $pdo->prepare("SELECT id FROM delivery_tasks WHERE order_id = ?");
                $stmt->execute([intval($order_id)]);

                if ($stmt->rowCount() == 0) {
                    // 获取收货地址
                    $delivery_address = $order['member_address'] ?: '未设置地址';

                    // 设置预计送达时间（当前时间+2小时）
                    $expected_time = date('Y-m-d H:i:s', strtotime('+2 hours'));

                    // 创建配送任务
                    $stmt = $pdo->prepare("
                        INSERT INTO delivery_tasks (
                            order_id, delivery_type, expected_time, 
                            route_info, status, create_time, update_time
                        ) VALUES (
                            ?, 1, ?, ?, 1, NOW(), NOW()
                        )
                    ");

                    $result = $stmt->execute([
                        intval($order_id),
                        $expected_time,
                        $delivery_address
                    ]);

                    if ($result) {
                        record_log("为订单 #{$order['order_no']} 创建了配送任务");
                        $created_count++;
                    } else {
                        $failed_count++;
                    }
                }
            }
        }

        $pdo->commit();

        if ($created_count > 0) {
            $success = "成功创建 {$created_count} 个配送任务";
            if ($failed_count > 0) {
                $success .= "，{$failed_count} 个任务创建失败";
            }
        } else {
            $error = "没有创建任何配送任务，可能订单已有配送任务或状态不正确";
        }
    } catch (Exception $e) {
        $pdo->rollBack();
        $error = "创建配送任务时发生错误：" . $e->getMessage();
    }
}

// 获取所有待配送订单（没有对应配送任务的）
$stmt = $pdo->query("
    SELECT o.*, m.name as member_name, m.phone as member_phone, m.address as member_address
    FROM orders o 
    LEFT JOIN members m ON o.member_id = m.id
    WHERE o.status = 3
    AND NOT EXISTS (
        SELECT 1 FROM delivery_tasks dt WHERE dt.order_id = o.id
    )
    ORDER BY o.create_time ASC
");
$pending_orders = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>创建配送任务</h2>
            <div class="breadcrumb">
                <a href="../index.php">首页</a> &gt;
                <a href="index.php">配送管理</a> &gt;
                <a href="task.php">配送任务</a> &gt;
                <span>创建配送任务</span>
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="task.php" class="btn btn-secondary">返回配送任务列表</a>
            </div>

            <h3 style="margin-top: 20px;">待配送订单列表</h3>

            <?php if (empty($pending_orders)): ?>
                <div class="alert alert-info">当前没有待处理的配送订单</div>
            <?php else: ?>
                <form method="post" action="create_delivery_task.php">
                    <div class="table-container">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th width="50"><input type="checkbox" id="select-all" onclick="toggleSelectAll()"></th>
                                    <th>订单编号</th>
                                    <th>会员信息</th>
                                    <th>订单金额</th>
                                    <th>配送地址</th>
                                    <th>下单时间</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($pending_orders as $order): ?>
                                    <tr>
                                        <td><input type="checkbox" name="order_ids[]" value="<?php echo $order['id']; ?>" class="order-checkbox"></td>
                                        <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                        <td>
                                            <?php if ($order['member_id']): ?>
                                                <?php echo htmlspecialchars($order['member_name']); ?> (<?php echo htmlspecialchars($order['member_phone']); ?>)
                                            <?php else: ?>
                                                非会员订单
                                            <?php endif; ?>
                                        </td>
                                        <td>￥<?php echo number_format($order['actual_amount'], 2); ?></td>
                                        <td><?php echo htmlspecialchars($order['member_address'] ?: '未设置地址'); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></td>
                                        <td>
                                            <a href="create_delivery_task.php?order_id=<?php echo $order['id']; ?>" class="btn btn-sm btn-primary">创建配送任务</a>
                                            <a href="../order/info.php?id=<?php echo $order['id']; ?>" class="btn btn-sm btn-secondary">查看订单</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <div class="form-actions" style="margin-top: 15px;">
                        <button type="submit" name="create_tasks" class="btn btn-primary">批量创建配送任务</button>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    </div>

    <script>
        function toggleSelectAll() {
            const selectAll = document.getElementById('select-all');
            const checkboxes = document.getElementsByClassName('order-checkbox');

            for (let i = 0; i < checkboxes.length; i++) {
                checkboxes[i].checked = selectAll.checked;
            }
        }
    </script>
</body>

</html>