<?php
// member/points.php - 会员积分管理
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('member.view');

// 处理操作请求
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$message = '';
$messageType = '';

// 获取会员列表（用于选择会员）
$stmt = $pdo->query("SELECT id, name, phone, points FROM members ORDER BY id");
$membersList = $stmt->fetchAll();

// 处理积分调整
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'adjust') {
    // 检查编辑权限
    check_permission_or_die('member.edit');

    $member_id = $_POST['member_id'] ?? 0;
    $type = $_POST['type'] ?? 1; // 1: 增加, 2: 减少
    $points = intval($_POST['points'] ?? 0);
    $source = $_POST['source'] ?? '';
    $remark = $_POST['remark'] ?? '';

    if (empty($member_id) || $points <= 0 || empty($source)) {
        $message = '请填写所有必填字段，积分必须大于0';
        $messageType = 'danger';
    } else {
        try {
            $pdo->beginTransaction();

            // 查询会员当前积分
            $stmt = $pdo->prepare("SELECT points, name FROM members WHERE id = ?");
            $stmt->execute([$member_id]);
            $member = $stmt->fetch();

            if (!$member) {
                throw new Exception('会员不存在');
            }

            $currentPoints = $member['points'];
            $memberName = $member['name'];

            // 计算积分变动后的值
            $pointsAfter = $type == 1 ? ($currentPoints + $points) : ($currentPoints - $points);

            // 如果是减少积分，确保不会出现负数
            if ($type == 2 && $pointsAfter < 0) {
                throw new Exception('会员积分不足，无法扣减');
            }

            // 更新会员积分
            $stmt = $pdo->prepare("UPDATE members SET points = ? WHERE id = ?");
            $stmt->execute([$pointsAfter, $member_id]);

            // 记录积分变动
            $stmt = $pdo->prepare("INSERT INTO member_points_log (member_id, type, points, source, remark) VALUES (?, ?, ?, ?, ?)");
            $stmt->execute([$member_id, $type, $points, $source, $remark]);

            // 如果积分达到下一等级，自动升级
            if ($type == 1) {
                $stmt = $pdo->prepare("SELECT id, min_points FROM member_levels WHERE min_points <= ? ORDER BY min_points DESC LIMIT 1");
                $stmt->execute([$pointsAfter]);
                $newLevel = $stmt->fetch();

                if ($newLevel) {
                    $stmt = $pdo->prepare("UPDATE members SET level_id = ? WHERE id = ? AND level_id != ?");
                    $stmt->execute([$newLevel['id'], $member_id, $newLevel['id']]);
                }
            }

            $pdo->commit();

            $typeText = $type == 1 ? '增加' : '减少';
            record_log("调整会员积分: {$memberName} (ID: {$member_id}) {$typeText} {$points} 积分，来源: {$source}");
            $message = '积分调整成功';
            $messageType = 'success';
            $action = 'list';
        } catch (Exception $e) {
            $pdo->rollBack();
            $message = '积分调整失败: ' . $e->getMessage();
            $messageType = 'danger';
        }
    }
}

// 获取积分记录列表（用于列表视图）
$logs = [];
if ($action === 'list') {
    // 分页参数
    $page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
    $limit = 10;
    $offset = ($page - 1) * $limit;

    // 搜索条件
    $searchMember = isset($_GET['search_member']) ? $_GET['search_member'] : '';
    $searchType = isset($_GET['search_type']) ? $_GET['search_type'] : '';
    $searchSource = isset($_GET['search_source']) ? $_GET['search_source'] : '';
    $searchDateStart = isset($_GET['search_date_start']) ? $_GET['search_date_start'] : '';
    $searchDateEnd = isset($_GET['search_date_end']) ? $_GET['search_date_end'] : '';

    $where = [];
    $params = [];

    if (!empty($searchMember)) {
        $where[] = "l.member_id = ?";
        $params[] = $searchMember;
    }

    if ($searchType !== '') {
        $where[] = "l.type = ?";
        $params[] = $searchType;
    }

    if (!empty($searchSource)) {
        $where[] = "l.source = ?";
        $params[] = $searchSource;
    }

    if (!empty($searchDateStart)) {
        $where[] = "DATE(l.create_time) >= ?";
        $params[] = $searchDateStart;
    }

    if (!empty($searchDateEnd)) {
        $where[] = "DATE(l.create_time) <= ?";
        $params[] = $searchDateEnd;
    }

    $whereClause = empty($where) ? "" : "WHERE " . implode(" AND ", $where);

    // 获取总记录数
    $countSql = "SELECT COUNT(*) as total FROM member_points_log l $whereClause";
    $stmt = $pdo->prepare($countSql);
    $stmt->execute($params);
    $totalRecords = $stmt->fetch()['total'];
    $totalPages = ceil($totalRecords / $limit);

    // 获取分页数据
    $sql = "SELECT l.*, m.name as member_name FROM member_points_log l
            LEFT JOIN members m ON l.member_id = m.id
            $whereClause
            ORDER BY l.create_time DESC LIMIT $offset, $limit";
    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $logs = $stmt->fetchAll();

    // 获取积分来源选项（用于搜索过滤）
    $stmt = $pdo->query("SELECT DISTINCT source FROM member_points_log ORDER BY source");
    $sourceOptions = $stmt->fetchAll(PDO::FETCH_COLUMN);
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>会员积分管理 - FloraEase</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员积分管理</h2>
            <div class="breadcrumb">
                <a href="index.php">会员管理</a> / 积分管理
            </div>
        </div>

        <div class="content">
            <?php if (!empty($message)): ?>
                <div class="alert alert-<?php echo $messageType; ?>">
                    <?php echo $message; ?>
                </div>
            <?php endif; ?>

            <?php if ($action === 'list'): ?>
                <!-- 操作栏 -->
                <div class="action-bar">
                    <?php if (has_permission('member.edit')): ?>
                        <a href="?action=adjust" class="btn btn-primary">积分调整</a>
                    <?php endif; ?>
                </div>

                <!-- 搜索表单 -->
                <form method="get" action="points.php" class="filter-form">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="search_member">会员</label>
                            <select id="search_member" name="search_member">
                                <option value="">全部会员</option>
                                <?php foreach ($membersList as $member): ?>
                                    <option value="<?php echo $member['id']; ?>" <?php echo $searchMember == $member['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($member['name']) . ' (' . htmlspecialchars($member['phone']) . ')'; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="search_type">操作类型</label>
                            <select id="search_type" name="search_type">
                                <option value="">全部</option>
                                <option value="1" <?php echo $searchType === '1' ? 'selected' : ''; ?>>增加</option>
                                <option value="2" <?php echo $searchType === '2' ? 'selected' : ''; ?>>减少</option>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="search_source">积分来源</label>
                            <select id="search_source" name="search_source">
                                <option value="">全部</option>
                                <?php foreach ($sourceOptions as $source): ?>
                                    <option value="<?php echo htmlspecialchars($source); ?>" <?php echo $searchSource === $source ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($source); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="search_date_start">开始日期</label>
                            <input type="date" id="search_date_start" name="search_date_start" value="<?php echo htmlspecialchars($searchDateStart ?? ''); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="search_date_end">结束日期</label>
                            <input type="date" id="search_date_end" name="search_date_end" value="<?php echo htmlspecialchars($searchDateEnd ?? ''); ?>">
                        </div>
                    </div>
                    <div class="filter-buttons">
                        <button type="submit" class="btn btn-primary">搜索</button>
                        <a href="?action=list" class="btn btn-secondary">重置</a>
                    </div>
                </form>

                <!-- 积分记录列表 -->
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>会员</th>
                                <th>操作类型</th>
                                <th>积分变动</th>
                                <th>积分来源</th>
                                <th>备注</th>
                                <th>操作时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($logs as $log): ?>
                                <tr>
                                    <td><?php echo $log['id']; ?></td>
                                    <td><?php echo htmlspecialchars($log['member_name']); ?></td>
                                    <td>
                                        <?php if ($log['type'] == 1): ?>
                                            <span class="status-active">增加</span>
                                        <?php else: ?>
                                            <span class="status-inactive">减少</span>
                                        <?php endif; ?>
                                    </td>
                                    <td><?php echo $log['points']; ?></td>
                                    <td><?php echo htmlspecialchars($log['source']); ?></td>
                                    <td><?php echo htmlspecialchars($log['remark'] ?? ''); ?></td>
                                    <td><?php echo $log['create_time']; ?></td>
                                </tr>
                            <?php endforeach; ?>
                            <?php if (empty($logs)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无积分记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 分页 -->
                <?php if ($totalPages > 1): ?>
                    <div class="pagination">
                        <?php if ($page > 1): ?>
                            <a href="?action=list&page=1<?php echo !empty($searchMember) ? '&search_member=' . $searchMember : ''; ?><?php echo $searchType !== '' ? '&search_type=' . $searchType : ''; ?><?php echo !empty($searchSource) ? '&search_source=' . urlencode($searchSource) : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">首页</a>
                            <a href="?action=list&page=<?php echo $page - 1; ?><?php echo !empty($searchMember) ? '&search_member=' . $searchMember : ''; ?><?php echo $searchType !== '' ? '&search_type=' . $searchType : ''; ?><?php echo !empty($searchSource) ? '&search_source=' . urlencode($searchSource) : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">上一页</a>
                        <?php endif; ?>

                        <?php
                        $startPage = max(1, $page - 2);
                        $endPage = min($totalPages, $page + 2);

                        for ($i = $startPage; $i <= $endPage; $i++):
                        ?>
                            <a href="?action=list&page=<?php echo $i; ?><?php echo !empty($searchMember) ? '&search_member=' . $searchMember : ''; ?><?php echo $searchType !== '' ? '&search_type=' . $searchType : ''; ?><?php echo !empty($searchSource) ? '&search_source=' . urlencode($searchSource) : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>"><?php echo $i; ?></a>
                        <?php endfor; ?>

                        <?php if ($page < $totalPages): ?>
                            <a href="?action=list&page=<?php echo $page + 1; ?><?php echo !empty($searchMember) ? '&search_member=' . $searchMember : ''; ?><?php echo $searchType !== '' ? '&search_type=' . $searchType : ''; ?><?php echo !empty($searchSource) ? '&search_source=' . urlencode($searchSource) : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">下一页</a>
                            <a href="?action=list&page=<?php echo $totalPages; ?><?php echo !empty($searchMember) ? '&search_member=' . $searchMember : ''; ?><?php echo $searchType !== '' ? '&search_type=' . $searchType : ''; ?><?php echo !empty($searchSource) ? '&search_source=' . urlencode($searchSource) : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">末页</a>
                        <?php endif; ?>
                    </div>
                    <div class="pagination-info">
                        共 <?php echo $totalRecords; ?> 条记录，当前 <?php echo $page; ?>/<?php echo $totalPages; ?> 页
                    </div>
                <?php endif; ?>

            <?php elseif ($action === 'adjust'): ?>
                <!-- 积分调整表单 -->
                <form method="post" action="?action=adjust" class="form-container">
                    <h3>积分调整</h3>

                    <div class="form-group">
                        <label for="member_id">选择会员 *</label>
                        <select id="member_id" name="member_id" required>
                            <option value="">请选择会员</option>
                            <?php foreach ($membersList as $member): ?>
                                <option value="<?php echo $member['id']; ?>">
                                    <?php echo htmlspecialchars($member['name']) . ' (' . htmlspecialchars($member['phone']) . ') - 当前积分: ' . $member['points']; ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="type">操作类型 *</label>
                        <select id="type" name="type" required>
                            <option value="1">增加积分</option>
                            <option value="2">减少积分</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="points">积分数量 *</label>
                        <input type="number" id="points" name="points" min="1" required>
                    </div>

                    <div class="form-group">
                        <label for="source">积分来源 *</label>
                        <select id="source" name="source" required>
                            <option value="">请选择来源</option>
                            <option value="购物">购物</option>
                            <option value="充值">充值</option>
                            <option value="推荐">推荐好友</option>
                            <option value="兑换">积分兑换</option>
                            <option value="活动">参与活动</option>
                            <option value="系统">系统调整</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="remark">备注</label>
                        <input type="text" id="remark" name="remark" placeholder="请输入备注信息">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">提交</button>
                        <a href="?action=list" class="btn btn-secondary">取消</a>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>