<?php
// member/recharge.php - 会员充值管理
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('member.view');

// 处理操作请求
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$message = '';
$messageType = '';

// 获取会员列表（用于选择会员）
$stmt = $pdo->query("SELECT id, name, phone, balance FROM members ORDER BY id");
$membersList = $stmt->fetchAll();

// 处理会员充值
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'recharge') {
    // 检查编辑权限
    check_permission_or_die('member.edit');

    $member_id = $_POST['member_id'] ?? 0;
    $amount = floatval($_POST['amount'] ?? 0);
    $extra_percent = floatval($_POST['extra_percent'] ?? 0);
    $remark = $_POST['remark'] ?? '';

    if (empty($member_id) || $amount <= 0) {
        $message = '请填写所有必填字段，充值金额必须大于0';
        $messageType = 'danger';
    } else {
        try {
            $pdo->beginTransaction();

            // 查询会员当前余额
            $stmt = $pdo->prepare("SELECT balance, name FROM members WHERE id = ?");
            $stmt->execute([$member_id]);
            $member = $stmt->fetch();

            if (!$member) {
                throw new Exception('会员不存在');
            }

            $currentBalance = $member['balance'];
            $memberName = $member['name'];

            // 计算实际充值金额（含优惠）
            $extra_amount = $amount * ($extra_percent / 100);
            $actual_amount = $amount + $extra_amount;
            $balanceAfter = $currentBalance + $actual_amount;

            // 更新会员余额
            $stmt = $pdo->prepare("UPDATE members SET balance = ? WHERE id = ?");
            $stmt->execute([$balanceAfter, $member_id]);

            // 记录充值记录
            $stmt = $pdo->prepare("INSERT INTO member_recharge_log (member_id, amount, actual_amount, remark) VALUES (?, ?, ?, ?)");
            $stmt->execute([$member_id, $amount, $actual_amount, $remark]);

            // 记录积分变动（如果充值赠送积分）
            if ($amount >= 100) {
                $points = intval($amount / 10); // 每充值10元赠送1积分

                // 更新会员积分
                $stmt = $pdo->prepare("UPDATE members SET points = points + ? WHERE id = ?");
                $stmt->execute([$points, $member_id]);

                // 记录积分变动
                $stmt = $pdo->prepare("INSERT INTO member_points_log (member_id, type, points, source, remark) VALUES (?, ?, ?, ?, ?)");
                $stmt->execute([$member_id, 1, $points, '充值', "充值{$amount}元赠送{$points}积分"]);
            }

            $pdo->commit();

            record_log("会员充值: {$memberName} (ID: {$member_id}) 充值 {$amount} 元，实际到账 {$actual_amount} 元");
            $message = '充值成功，实际到账金额：' . number_format($actual_amount, 2) . ' 元';
            $messageType = 'success';
            $action = 'list'; // 返回列表视图

        } catch (Exception $e) {
            $pdo->rollBack();
            $message = '充值失败: ' . $e->getMessage();
            $messageType = 'danger';
        }
    }
}

// 获取充值记录列表（用于列表视图）
$logs = [];
if ($action === 'list') {
    // 分页参数
    $page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
    $limit = 10;
    $offset = ($page - 1) * $limit;

    // 搜索条件
    $searchMember = isset($_GET['search_member']) ? $_GET['search_member'] : '';
    $searchDateStart = isset($_GET['search_date_start']) ? $_GET['search_date_start'] : '';
    $searchDateEnd = isset($_GET['search_date_end']) ? $_GET['search_date_end'] : '';

    $where = [];
    $params = [];

    if (!empty($searchMember)) {
        $where[] = "r.member_id = ?";
        $params[] = $searchMember;
    }

    if (!empty($searchDateStart)) {
        $where[] = "DATE(r.create_time) >= ?";
        $params[] = $searchDateStart;
    }

    if (!empty($searchDateEnd)) {
        $where[] = "DATE(r.create_time) <= ?";
        $params[] = $searchDateEnd;
    }

    $whereClause = empty($where) ? "" : "WHERE " . implode(" AND ", $where);

    // 获取总记录数
    $countSql = "SELECT COUNT(*) as total FROM member_recharge_log r $whereClause";
    $stmt = $pdo->prepare($countSql);
    $stmt->execute($params);
    $totalRecords = $stmt->fetch()['total'];
    $totalPages = ceil($totalRecords / $limit);

    // 获取分页数据
    $sql = "SELECT r.*, m.name as member_name FROM member_recharge_log r
            LEFT JOIN members m ON r.member_id = m.id
            $whereClause
            ORDER BY r.create_time DESC LIMIT $offset, $limit";
    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $logs = $stmt->fetchAll();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>会员充值管理 - FloraEase</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员充值管理</h2>
            <div class="breadcrumb">
                <a href="index.php">会员管理</a> / 充值管理
            </div>
        </div>

        <div class="content">
            <?php if (!empty($message)): ?>
                <div class="alert alert-<?php echo $messageType; ?>">
                    <?php echo $message; ?>
                </div>
            <?php endif; ?>

            <?php if ($action === 'list'): ?>
                <!-- 操作栏 -->
                <div class="action-bar">
                    <?php if (has_permission('member.edit')): ?>
                        <a href="?action=recharge" class="btn btn-primary">会员充值</a>
                    <?php endif; ?>
                </div>

                <!-- 搜索表单 -->
                <form method="get" action="recharge.php" class="filter-form">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="search_member">会员</label>
                            <select id="search_member" name="search_member">
                                <option value="">全部会员</option>
                                <?php foreach ($membersList as $member): ?>
                                    <option value="<?php echo $member['id']; ?>" <?php echo $searchMember == $member['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($member['name']) . ' (' . htmlspecialchars($member['phone']) . ')'; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="search_date_start">开始日期</label>
                            <input type="date" id="search_date_start" name="search_date_start" value="<?php echo htmlspecialchars($searchDateStart ?? ''); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="search_date_end">结束日期</label>
                            <input type="date" id="search_date_end" name="search_date_end" value="<?php echo htmlspecialchars($searchDateEnd ?? ''); ?>">
                        </div>
                    </div>
                    <div class="filter-buttons">
                        <button type="submit" class="btn btn-primary">搜索</button>
                        <a href="?action=list" class="btn btn-secondary">重置</a>
                    </div>
                </form>

                <!-- 充值记录列表 -->
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>会员</th>
                                <th>充值金额</th>
                                <th>实际到账</th>
                                <th>赠送比例</th>
                                <th>备注</th>
                                <th>充值时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($logs as $log): ?>
                                <tr>
                                    <td><?php echo $log['id']; ?></td>
                                    <td><?php echo htmlspecialchars($log['member_name']); ?></td>
                                    <td>￥<?php echo number_format($log['amount'], 2); ?></td>
                                    <td>￥<?php echo number_format($log['actual_amount'], 2); ?></td>
                                    <td><?php echo round(($log['actual_amount'] - $log['amount']) / $log['amount'] * 100, 1); ?>%</td>
                                    <td><?php echo htmlspecialchars($log['remark'] ?? ''); ?></td>
                                    <td><?php echo $log['create_time']; ?></td>
                                </tr>
                            <?php endforeach; ?>
                            <?php if (empty($logs)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无充值记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 分页 -->
                <?php if ($totalPages > 1): ?>
                    <div class="pagination">
                        <?php if ($page > 1): ?>
                            <a href="?action=list&page=1<?php echo !empty($searchMember) ? '&search_member=' . $searchMember : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">首页</a>
                            <a href="?action=list&page=<?php echo $page - 1; ?><?php echo !empty($searchMember) ? '&search_member=' . $searchMember : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">上一页</a>
                        <?php endif; ?>

                        <?php
                        $startPage = max(1, $page - 2);
                        $endPage = min($totalPages, $page + 2);

                        for ($i = $startPage; $i <= $endPage; $i++):
                        ?>
                            <a href="?action=list&page=<?php echo $i; ?><?php echo !empty($searchMember) ? '&search_member=' . $searchMember : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>"><?php echo $i; ?></a>
                        <?php endfor; ?>

                        <?php if ($page < $totalPages): ?>
                            <a href="?action=list&page=<?php echo $page + 1; ?><?php echo !empty($searchMember) ? '&search_member=' . $searchMember : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">下一页</a>
                            <a href="?action=list&page=<?php echo $totalPages; ?><?php echo !empty($searchMember) ? '&search_member=' . $searchMember : ''; ?><?php echo !empty($searchDateStart) ? '&search_date_start=' . $searchDateStart : ''; ?><?php echo !empty($searchDateEnd) ? '&search_date_end=' . $searchDateEnd : ''; ?>" class="page-link">末页</a>
                        <?php endif; ?>
                    </div>
                    <div class="pagination-info">
                        共 <?php echo $totalRecords; ?> 条记录，当前 <?php echo $page; ?>/<?php echo $totalPages; ?> 页
                    </div>
                <?php endif; ?>

            <?php elseif ($action === 'recharge'): ?>
                <!-- 会员充值表单 -->
                <form method="post" action="?action=recharge" class="form-container">
                    <h3>会员充值</h3>

                    <div class="form-group">
                        <label for="member_id">选择会员 *</label>
                        <select id="member_id" name="member_id" required>
                            <option value="">请选择会员</option>
                            <?php foreach ($membersList as $member): ?>
                                <option value="<?php echo $member['id']; ?>">
                                    <?php echo htmlspecialchars($member['name']) . ' (' . htmlspecialchars($member['phone']) . ') - 当前余额: ￥' . number_format($member['balance'], 2); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="amount">充值金额(元) *</label>
                        <input type="number" id="amount" name="amount" min="1" step="0.01" required onchange="calculateBonus()">
                    </div>

                    <div class="form-group">
                        <label for="extra_percent">赠送比例(%)</label>
                        <select id="extra_percent" name="extra_percent" onchange="calculateBonus()">
                            <option value="0">无赠送</option>
                            <option value="5">5%</option>
                            <option value="10">10%</option>
                            <option value="15">15%</option>
                            <option value="20">20%</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="actual_amount">实际到账(元)</label>
                        <input type="text" id="actual_amount" readonly>
                    </div>

                    <div class="form-group">
                        <label for="remark">备注</label>
                        <input type="text" id="remark" name="remark" placeholder="请输入备注信息">
                    </div>

                    <div class="info-box">
                        <h3>充值优惠说明</h3>
                        <ul>
                            <li>充值满100元，可获得10积分奖励</li>
                            <li>充值200元以上，可享受5%的余额赠送</li>
                            <li>充值500元以上，可享受10%的余额赠送</li>
                            <li>充值1000元以上，可享受15%的余额赠送</li>
                            <li>充值2000元以上，可享受20%的余额赠送</li>
                        </ul>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">充值</button>
                        <a href="?action=list" class="btn btn-secondary">取消</a>
                    </div>
                </form>

                <script>
                    function calculateBonus() {
                        let amount = parseFloat(document.getElementById('amount').value) || 0;
                        let extraPercent = parseFloat(document.getElementById('extra_percent').value) || 0;

                        // 根据充值金额自动选择优惠比例
                        if (amount >= 2000 && document.getElementById('extra_percent').value === '0') {
                            document.getElementById('extra_percent').value = '20';
                            extraPercent = 20;
                        } else if (amount >= 1000 && amount < 2000 && document.getElementById('extra_percent').value === '0') {
                            document.getElementById('extra_percent').value = '15';
                            extraPercent = 15;
                        } else if (amount >= 500 && amount < 1000 && document.getElementById('extra_percent').value === '0') {
                            document.getElementById('extra_percent').value = '10';
                            extraPercent = 10;
                        } else if (amount >= 200 && amount < 500 && document.getElementById('extra_percent').value === '0') {
                            document.getElementById('extra_percent').value = '5';
                            extraPercent = 5;
                        }

                        let extraAmount = amount * (extraPercent / 100);
                        let actualAmount = amount + extraAmount;

                        document.getElementById('actual_amount').value = '￥' + actualAmount.toFixed(2);
                    }

                    // 页面加载时初始化计算
                    document.addEventListener('DOMContentLoaded', function() {
                        calculateBonus();
                    });
                </script>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>