<?php
// product/inventory.php - 库存管理页面
session_start();
require_once '../database_config.php';

// 检查用户是否有访问权限
check_permission_or_die('inventory');

// 处理库存操作
$message = '';
$message_type = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 验证必填字段
    $required_fields = ['product_id', 'quantity'];
    $missing_fields = [];

    foreach ($required_fields as $field) {
        if (!isset($_POST[$field]) || $_POST[$field] === '') {
            $missing_fields[] = $field;
        }
    }

    if (!empty($missing_fields)) {
        $message = '请填写所有必填字段';
        $message_type = 'danger';
    } else {
        $product_id = $_POST['product_id'];
        $quantity = intval($_POST['quantity']);
        $remark = isset($_POST['remark']) ? $_POST['remark'] : '';
        $operator = $_SESSION['username'];

        try {
            // 获取当前库存
            $stmt = $pdo->prepare("SELECT stock FROM products WHERE id = ?");
            $stmt->execute([$product_id]);
            $current_stock = $stmt->fetch()['stock'];

            $type = 0;
            $new_quantity = $quantity;

            // 根据不同操作类型处理
            switch ($_POST['action']) {
                case 'purchase': // 采购入库
                    $type = 1;
                    $supplier_id = $_POST['supplier_id'];
                    $price = $_POST['price'];
                    $after_stock = $current_stock + $quantity;

                    // 记录库存变动
                    $stmt = $pdo->prepare("INSERT INTO inventory_records (product_id, type, quantity, before_stock, after_stock, price, supplier_id, remark, operator) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
                    $stmt->execute([$product_id, $type, $quantity, $current_stock, $after_stock, $price, $supplier_id, $remark, $operator]);

                    // 更新商品库存
                    $stmt = $pdo->prepare("UPDATE products SET stock = ? WHERE id = ?");
                    $stmt->execute([$after_stock, $product_id]);

                    $message = '采购入库成功！';
                    $message_type = 'success';
                    break;

                case 'sale': // 销售出库
                    $type = 2;
                    $price = $_POST['price'];
                    $new_quantity = -$quantity; // 出库为负数
                    $after_stock = $current_stock - $quantity;

                    // 检查库存是否足够
                    if ($after_stock < 0) {
                        $message = '库存不足，无法出库！';
                        $message_type = 'danger';
                        break;
                    }

                    // 记录库存变动
                    $stmt = $pdo->prepare("INSERT INTO inventory_records (product_id, type, quantity, before_stock, after_stock, price, remark, operator) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
                    $stmt->execute([$product_id, $type, $new_quantity, $current_stock, $after_stock, $price, $remark, $operator]);

                    // 更新商品库存
                    $stmt = $pdo->prepare("UPDATE products SET stock = ? WHERE id = ?");
                    $stmt->execute([$after_stock, $product_id]);

                    $message = '销售出库成功！';
                    $message_type = 'success';
                    break;

                case 'loss': // 报损记录
                    $type = 3;
                    $new_quantity = -$quantity; // 报损为负数
                    $after_stock = $current_stock - $quantity;

                    // 检查库存是否足够
                    if ($after_stock < 0) {
                        $message = '库存不足，无法报损！';
                        $message_type = 'danger';
                        break;
                    }

                    // 记录库存变动
                    $stmt = $pdo->prepare("INSERT INTO inventory_records (product_id, type, quantity, before_stock, after_stock, remark, operator) VALUES (?, ?, ?, ?, ?, ?, ?)");
                    $stmt->execute([$product_id, $type, $new_quantity, $current_stock, $after_stock, $remark, $operator]);

                    // 更新商品库存
                    $stmt = $pdo->prepare("UPDATE products SET stock = ? WHERE id = ?");
                    $stmt->execute([$after_stock, $product_id]);

                    $message = '报损记录成功！';
                    $message_type = 'success';
                    break;

                case 'adjust': // 盘点调整
                    $type = 4;
                    $actual_stock = $quantity;
                    $diff_quantity = $actual_stock - $current_stock;
                    $after_stock = $actual_stock;

                    // 记录库存变动
                    $stmt = $pdo->prepare("INSERT INTO inventory_records (product_id, type, quantity, before_stock, after_stock, remark, operator) VALUES (?, ?, ?, ?, ?, ?, ?)");
                    $stmt->execute([$product_id, $type, $diff_quantity, $current_stock, $after_stock, $remark, $operator]);

                    // 更新商品库存
                    $stmt = $pdo->prepare("UPDATE products SET stock = ? WHERE id = ?");
                    $stmt->execute([$after_stock, $product_id]);

                    $message = '库存盘点调整成功！';
                    $message_type = 'success';
                    break;
            }

            // 记录操作日志
            $product_stmt = $pdo->prepare("SELECT name FROM products WHERE id = ?");
            $product_stmt->execute([$product_id]);
            $product_name = $product_stmt->fetch()['name'];

            record_log("库存操作: {$_POST['action']} - 商品: {$product_name}, 数量: {$new_quantity}");
        } catch (PDOException $e) {
            $message = '操作失败: ' . $e->getMessage();
            $message_type = 'danger';
        }
    }
}

// 获取商品列表
$stmt = $pdo->query("SELECT id, name, code FROM products ORDER BY name");
$products = $stmt->fetchAll();

// 获取供应商列表
$stmt = $pdo->query("SELECT id, name FROM suppliers ORDER BY name");
$suppliers = $stmt->fetchAll();

// 库存记录分页
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$limit = 20;
$offset = ($page - 1) * $limit;

// 构建查询条件
$where_conditions = [];
$params = [];

// 筛选条件
$filter_product = isset($_GET['product_id']) ? $_GET['product_id'] : '';
if (!empty($filter_product)) {
    $where_conditions[] = "i.product_id = ?";
    $params[] = $filter_product;
}

// 添加供应商筛选
$filter_supplier = isset($_GET['supplier_id']) ? $_GET['supplier_id'] : '';
if (!empty($filter_supplier)) {
    $where_conditions[] = "i.supplier_id = ?";
    $params[] = $filter_supplier;
}

$filter_type = isset($_GET['type']) ? $_GET['type'] : '';
if ($filter_type !== '' && $filter_type >= 1 && $filter_type <= 4) {
    $where_conditions[] = "i.type = ?";
    $params[] = $filter_type;
}

$filter_date_start = isset($_GET['date_start']) ? $_GET['date_start'] : '';
if (!empty($filter_date_start)) {
    $where_conditions[] = "i.create_time >= ?";
    $params[] = $filter_date_start . ' 00:00:00';
}

$filter_date_end = isset($_GET['date_end']) ? $_GET['date_end'] : '';
if (!empty($filter_date_end)) {
    $where_conditions[] = "i.create_time <= ?";
    $params[] = $filter_date_end . ' 23:59:59';
}

// 构建WHERE子句
$where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

// 获取总记录数
$count_sql = "SELECT COUNT(*) as total FROM inventory_records i $where_clause";
$stmt = $pdo->prepare($count_sql);
$stmt->execute($params);
$total_records = $stmt->fetch()['total'];
$total_pages = ceil($total_records / $limit);

// 获取分页数据
$sql = "SELECT i.*, p.name as product_name, p.code as product_code, s.name as supplier_name 
        FROM inventory_records i 
        LEFT JOIN products p ON i.product_id = p.id 
        LEFT JOIN suppliers s ON i.supplier_id = s.id 
        $where_clause 
        ORDER BY i.create_time DESC 
        LIMIT $offset, $limit";

$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$records = $stmt->fetchAll();

// 预加载GET数据（用于表单预填充）
$action = isset($_GET['action']) ? $_GET['action'] : '';
$pre_product_id = isset($_GET['product_id']) ? $_GET['product_id'] : '';

// 获取预选商品信息
$preselected_product = null;
if (!empty($pre_product_id)) {
    $stmt = $pdo->prepare("SELECT * FROM products WHERE id = ?");
    $stmt->execute([$pre_product_id]);
    $preselected_product = $stmt->fetch();
}

// 记录操作日志
record_log("访问库存管理页面");
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>库存管理 - <?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>库存管理</h2>
            <div class="breadcrumb">
                <a href="index.php">商品与库存管理</a> &gt;
                库存管理
            </div>
        </div>

        <div class="content">
            <?php if (!empty($message)): ?>
                <div class="alert alert-<?php echo $message_type; ?>">
                    <?php echo $message; ?>
                </div>
            <?php endif; ?>

            <!-- 操作按钮 -->
            <div class="action-bar">
                <button class="btn btn-primary" onclick="showForm('purchase')">采购入库</button>
                <button class="btn btn-secondary" onclick="showForm('sale')">销售出库</button>
                <button class="btn btn-danger" onclick="showForm('loss')">商品报损</button>
                <button class="btn btn-secondary" onclick="showForm('adjust')">库存盘点</button>
            </div>

            <!-- 库存操作表单（默认隐藏） -->
            <div id="purchaseForm" class="form-container" style="display: <?php echo $action == 'purchase' ? 'block' : 'none'; ?>;">
                <h3>采购入库</h3>
                <form method="post" action="inventory.php">
                    <input type="hidden" name="action" value="purchase">

                    <div class="form-group">
                        <label for="product_id">选择商品 <span class="text-danger">*</span></label>
                        <select name="product_id" id="product_id" required>
                            <option value="">请选择商品</option>
                            <?php foreach ($products as $product): ?>
                                <option value="<?php echo $product['id']; ?>" <?php echo $pre_product_id == $product['id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($product['name'] . ' (' . $product['code'] . ')'); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="supplier_id">供应商 <span class="text-danger">*</span></label>
                        <select name="supplier_id" id="supplier_id" required>
                            <option value="">请选择供应商</option>
                            <?php foreach ($suppliers as $supplier): ?>
                                <option value="<?php echo $supplier['id']; ?>">
                                    <?php echo htmlspecialchars($supplier['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="quantity">采购数量 <span class="text-danger">*</span></label>
                        <input type="number" id="quantity" name="quantity" min="1" required>
                    </div>

                    <div class="form-group">
                        <label for="price">采购单价 <span class="text-danger">*</span></label>
                        <input type="number" id="price" name="price" step="0.01" min="0" required>
                    </div>

                    <div class="form-group">
                        <label for="remark">备注</label>
                        <input type="text" id="remark" name="remark">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">确认入库</button>
                        <button type="button" class="btn btn-secondary" onclick="hideForm('purchase')">取消</button>
                    </div>
                </form>
            </div>

            <div id="saleForm" class="form-container" style="display: <?php echo $action == 'sale' ? 'block' : 'none'; ?>;">
                <h3>销售出库</h3>
                <form method="post" action="inventory.php">
                    <input type="hidden" name="action" value="sale">

                    <div class="form-group">
                        <label for="sale_product_id">选择商品 <span class="text-danger">*</span></label>
                        <select name="product_id" id="sale_product_id" required>
                            <option value="">请选择商品</option>
                            <?php foreach ($products as $product): ?>
                                <option value="<?php echo $product['id']; ?>" <?php echo $pre_product_id == $product['id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($product['name'] . ' (' . $product['code'] . ')'); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="sale_quantity">出库数量 <span class="text-danger">*</span></label>
                        <input type="number" id="sale_quantity" name="quantity" min="1" required>
                    </div>

                    <div class="form-group">
                        <label for="sale_price">销售单价 <span class="text-danger">*</span></label>
                        <input type="number" id="sale_price" name="price" step="0.01" min="0" required
                            value="<?php echo isset($preselected_product) ? $preselected_product['price'] : ''; ?>">
                    </div>

                    <div class="form-group">
                        <label for="sale_remark">备注</label>
                        <input type="text" id="sale_remark" name="remark">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">确认出库</button>
                        <button type="button" class="btn btn-secondary" onclick="hideForm('sale')">取消</button>
                    </div>
                </form>
            </div>

            <div id="lossForm" class="form-container" style="display: <?php echo $action == 'loss' ? 'block' : 'none'; ?>;">
                <h3>商品报损</h3>
                <form method="post" action="inventory.php">
                    <input type="hidden" name="action" value="loss">

                    <div class="form-group">
                        <label for="loss_product_id">选择商品 <span class="text-danger">*</span></label>
                        <select name="product_id" id="loss_product_id" required>
                            <option value="">请选择商品</option>
                            <?php foreach ($products as $product): ?>
                                <option value="<?php echo $product['id']; ?>" <?php echo $pre_product_id == $product['id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($product['name'] . ' (' . $product['code'] . ')'); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="loss_quantity">报损数量 <span class="text-danger">*</span></label>
                        <input type="number" id="loss_quantity" name="quantity" min="1" required>
                    </div>

                    <div class="form-group">
                        <label for="loss_remark">报损原因 <span class="text-danger">*</span></label>
                        <input type="text" id="loss_remark" name="remark" required>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">确认报损</button>
                        <button type="button" class="btn btn-secondary" onclick="hideForm('loss')">取消</button>
                    </div>
                </form>
            </div>

            <div id="adjustForm" class="form-container" style="display: <?php echo $action == 'adjust' ? 'block' : 'none'; ?>;">
                <h3>库存盘点</h3>
                <form method="post" action="inventory.php">
                    <input type="hidden" name="action" value="adjust">

                    <div class="form-group">
                        <label for="adjust_product_id">选择商品 <span class="text-danger">*</span></label>
                        <select name="product_id" id="adjust_product_id" required onchange="getProductStock(this.value)">
                            <option value="">请选择商品</option>
                            <?php foreach ($products as $product): ?>
                                <option value="<?php echo $product['id']; ?>" <?php echo $pre_product_id == $product['id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($product['name'] . ' (' . $product['code'] . ')'); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>系统当前库存</label>
                        <input type="text" id="current_stock" disabled value="<?php echo isset($preselected_product) ? $preselected_product['stock'] : ''; ?>">
                    </div>

                    <div class="form-group">
                        <label for="adjust_quantity">实际库存数量 <span class="text-danger">*</span></label>
                        <input type="number" id="adjust_quantity" name="quantity" min="0" required>
                    </div>

                    <div class="form-group">
                        <label for="adjust_remark">备注</label>
                        <input type="text" id="adjust_remark" name="remark">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">确认调整</button>
                        <button type="button" class="btn btn-secondary" onclick="hideForm('adjust')">取消</button>
                    </div>
                </form>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="inventory.php">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="filter_product_id">商品</label>
                            <select name="product_id" id="filter_product_id">
                                <option value="">所有商品</option>
                                <?php foreach ($products as $product): ?>
                                    <option value="<?php echo $product['id']; ?>" <?php echo $filter_product == $product['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($product['name'] . ' (' . $product['code'] . ')'); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="filter_supplier_id">供应商</label>
                            <select name="supplier_id" id="filter_supplier_id">
                                <option value="">所有供应商</option>
                                <?php foreach ($suppliers as $supplier): ?>
                                    <option value="<?php echo $supplier['id']; ?>" <?php echo $filter_supplier == $supplier['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($supplier['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="filter_type">操作类型</label>
                            <select name="type" id="filter_type">
                                <option value="">所有类型</option>
                                <option value="1" <?php echo $filter_type === '1' ? 'selected' : ''; ?>>采购入库</option>
                                <option value="2" <?php echo $filter_type === '2' ? 'selected' : ''; ?>>销售出库</option>
                                <option value="3" <?php echo $filter_type === '3' ? 'selected' : ''; ?>>商品报损</option>
                                <option value="4" <?php echo $filter_type === '4' ? 'selected' : ''; ?>>库存盘点</option>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="filter_date_start">开始日期</label>
                            <input type="date" id="filter_date_start" name="date_start" value="<?php echo htmlspecialchars($filter_date_start); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="filter_date_end">结束日期</label>
                            <input type="date" id="filter_date_end" name="date_end" value="<?php echo htmlspecialchars($filter_date_end); ?>">
                        </div>
                        <div class="filter-item">
                            <label>&nbsp;</label>
                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="inventory.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 库存记录表格 -->
            <div class="table-responsive">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>时间</th>
                            <th>商品</th>
                            <th>操作类型</th>
                            <th>变动数量</th>
                            <th>变动前库存</th>
                            <th>变动后库存</th>
                            <th>单价</th>
                            <th>供应商</th>
                            <th>备注</th>
                            <th>操作员</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($records as $record):
                            // 设置类型文本和样式
                            $type_text = '';
                            $type_class = '';
                            switch ($record['type']) {
                                case 1:
                                    $type_text = '采购入库';
                                    $type_class = 'status-active';
                                    break;
                                case 2:
                                    $type_text = '销售出库';
                                    break;
                                case 3:
                                    $type_text = '报损';
                                    $type_class = 'status-inactive';
                                    break;
                                case 4:
                                    $type_text = '盘点调整';
                                    break;
                                default:
                                    $type_text = '未知';
                            }
                        ?>
                            <tr>
                                <td><?php echo $record['id']; ?></td>
                                <td><?php echo date('Y-m-d H:i', strtotime($record['create_time'])); ?></td>
                                <td><?php echo htmlspecialchars($record['product_name'] . ' (' . $record['product_code'] . ')'); ?></td>
                                <td class="<?php echo $type_class; ?>"><?php echo $type_text; ?></td>
                                <td><?php echo $record['quantity'] > 0 ? '+' . $record['quantity'] : $record['quantity']; ?></td>
                                <td><?php echo $record['before_stock']; ?></td>
                                <td><?php echo $record['after_stock']; ?></td>
                                <td><?php echo $record['price'] ? '￥' . number_format($record['price'], 2) : '-'; ?></td>
                                <td><?php echo $record['supplier_name'] ? htmlspecialchars($record['supplier_name']) : '-'; ?></td>
                                <td><?php echo htmlspecialchars($record['remark']); ?></td>
                                <td><?php echo htmlspecialchars($record['operator']); ?></td>
                            </tr>
                        <?php endforeach; ?>

                        <?php if (empty($records)): ?>
                            <tr>
                                <td colspan="11" class="text-center">没有找到符合条件的库存记录</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分页 -->
            <?php if ($total_pages > 1): ?>
                <div class="pagination">
                    <?php if ($page > 1): ?>
                        <a href="?page=1<?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">首页</a>
                        <a href="?page=<?php echo $page - 1; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">上一页</a>
                    <?php endif; ?>

                    <?php
                    $start_page = max(1, $page - 2);
                    $end_page = min($total_pages, $page + 2);

                    for ($i = $start_page; $i <= $end_page; $i++):
                    ?>
                        <a href="?page=<?php echo $i; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>">
                            <?php echo $i; ?>
                        </a>
                    <?php endfor; ?>

                    <?php if ($page < $total_pages): ?>
                        <a href="?page=<?php echo $page + 1; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">下一页</a>
                        <a href="?page=<?php echo $total_pages; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">末页</a>
                    <?php endif; ?>
                </div>
                <div class="pagination-info">
                    共 <?php echo $total_records; ?> 条记录，当前第 <?php echo $page; ?>/<?php echo $total_pages; ?> 页
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 显示指定表单
        function showForm(formType) {
            document.getElementById('purchaseForm').style.display = 'none';
            document.getElementById('saleForm').style.display = 'none';
            document.getElementById('lossForm').style.display = 'none';
            document.getElementById('adjustForm').style.display = 'none';

            document.getElementById(formType + 'Form').style.display = 'block';
        }

        // 隐藏指定表单
        function hideForm(formType) {
            document.getElementById(formType + 'Form').style.display = 'none';
        }

        // 获取商品库存
        function getProductStock(product_id) {
            if (product_id) {
                fetch(`get_product_stock.php?id=${product_id}`)
                    .then(response => response.json())
                    .then(data => {
                        document.getElementById('current_stock').value = data.stock;
                    })
                    .catch(error => console.error('Error:', error));
            } else {
                document.getElementById('current_stock').value = '';
            }
        }

        // 如果有预选商品，自动获取库存
        document.addEventListener('DOMContentLoaded', function() {
            const adjustProductId = document.getElementById('adjust_product_id');
            if (adjustProductId && adjustProductId.value) {
                getProductStock(adjustProductId.value);
            }
        });
    </script>
</body>

</html>