<?php
// statistics/inventory.php - 库存数据统计页面
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('statistics.view');

// 记录访问日志
record_log('访问库存数据统计页面');

// 处理日期筛选
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'month';
$custom_start = isset($_GET['custom_start']) ? $_GET['custom_start'] : '';
$custom_end = isset($_GET['custom_end']) ? $_GET['custom_end'] : '';
$category_id = isset($_GET['category_id']) ? (int)$_GET['category_id'] : 0;

// 根据选择的日期范围确定开始和结束日期
$start_date = '';
$end_date = date('Y-m-d');

switch ($date_range) {
    case 'today':
        $start_date = date('Y-m-d');
        break;
    case 'yesterday':
        $start_date = date('Y-m-d', strtotime('-1 day'));
        $end_date = date('Y-m-d', strtotime('-1 day'));
        break;
    case 'week':
        $start_date = date('Y-m-d', strtotime('-7 days'));
        break;
    case 'month':
        $start_date = date('Y-m-d', strtotime('-30 days'));
        break;
    case 'quarter':
        $start_date = date('Y-m-d', strtotime('-90 days'));
        break;
    case 'year':
        $start_date = date('Y-m-d', strtotime('-365 days'));
        break;
    case 'custom':
        if (!empty($custom_start)) {
            $start_date = $custom_start;
        } else {
            $start_date = date('Y-m-d', strtotime('-30 days'));
        }

        if (!empty($custom_end)) {
            $end_date = $custom_end;
        }
        break;
    default:
        $start_date = date('Y-m-d', strtotime('-30 days'));
}

// 获取产品分类列表
$categories = [];
try {
    $stmt = $pdo->query("SELECT id, name as category_name FROM product_categories ORDER BY id");
    $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取产品分类失败: ' . $e->getMessage();
}

// 获取库存概览数据
$inventory_overview = [
    'total_products' => 0,
    'total_inventory' => 0,
    'low_stock' => 0,
    'total_value' => 0,
];

try {
    // 获取总产品数、总库存量、低库存产品数
    $stmt = $pdo->query("
        SELECT 
            COUNT(*) as total_products,
            SUM(stock) as total_inventory,
            SUM(IF(stock <= warning_stock, 1, 0)) as low_stock,
            SUM(stock * cost_price) as total_value
        FROM products
    ");
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($result) {
        $inventory_overview['total_products'] = $result['total_products'] ?: 0;
        $inventory_overview['total_inventory'] = $result['total_inventory'] ?: 0;
        $inventory_overview['low_stock'] = $result['low_stock'] ?: 0;
        $inventory_overview['total_value'] = $result['total_value'] ?: 0;
    }
} catch (PDOException $e) {
    $error_message = '获取库存概览数据失败: ' . $e->getMessage();
}

// 库存周转率分析
$turnover_rate = [];

try {
    // 根据分类筛选条件构建WHERE子句
    $category_filter = '';
    $params = [$start_date . ' 00:00:00', $end_date . ' 23:59:59'];

    if ($category_id > 0) {
        $category_filter = " AND p.category_id = ? ";
        $params[] = $category_id;
    }

    // 计算库存周转率（销售量/平均库存）
    $stmt = $pdo->prepare("
        SELECT 
            p.id,
            p.name as product_name,
            p.code as product_code,
            pc.name as category_name,
            p.stock as current_stock,
            COALESCE(SUM(oi.quantity), 0) as sold_quantity,
            (
                CASE 
                    WHEN p.stock > 0 
                    THEN ROUND(COALESCE(SUM(oi.quantity), 0) / p.stock, 2)
                    ELSE 0 
                END
            ) as turnover_rate
        FROM products p
        LEFT JOIN product_categories pc ON p.category_id = pc.id
        LEFT JOIN order_items oi ON p.id = oi.product_id
        LEFT JOIN orders o ON oi.order_id = o.id AND o.create_time BETWEEN ? AND ? AND o.status IN (3, 4)
        WHERE 1=1 $category_filter
        GROUP BY p.id, p.name, p.code, pc.name, p.stock
        ORDER BY turnover_rate DESC
        LIMIT 20
    ");
    $stmt->execute($params);
    $turnover_rate = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取库存周转率数据失败: ' . $e->getMessage();
}

// 库存变动趋势（入库/出库）
$inventory_trend = [];
$period_type = isset($_GET['period_type']) ? $_GET['period_type'] : 'day';

try {
    $sql_format = '';
    switch ($period_type) {
        case 'day':
            $sql_format = '%Y-%m-%d';
            break;
        case 'week':
            $sql_format = '%Y-%u';
            break;
        case 'month':
            $sql_format = '%Y-%m';
            break;
    }

    // 构建分类筛选条件
    $category_filter = '';
    $params = [$sql_format, $start_date . ' 00:00:00', $end_date . ' 23:59:59'];

    if ($category_id > 0) {
        $category_filter = " AND p.category_id = ? ";
        $params[] = $category_id;
    }

    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(ir.create_time, ?) as period,
            SUM(CASE WHEN ir.type = 1 THEN ir.quantity ELSE 0 END) as in_quantity,
            SUM(CASE WHEN ir.type = 2 THEN ir.quantity ELSE 0 END) as out_quantity
        FROM inventory_records ir
        JOIN products p ON ir.product_id = p.id
        WHERE ir.create_time BETWEEN ? AND ?
        $category_filter
        GROUP BY period
        ORDER BY MIN(ir.create_time)
    ");
    $stmt->execute($params);
    $inventory_trend = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取库存变动趋势数据失败: ' . $e->getMessage();
}

// 采购成本分析（按供应商统计）
$purchase_by_supplier = [];

try {
    // 构建分类筛选条件
    $category_filter = '';
    $params = [$start_date . ' 00:00:00', $end_date . ' 23:59:59'];

    if ($category_id > 0) {
        $category_filter = " AND p.category_id = ? ";
        $params[] = $category_id;
    }

    $stmt = $pdo->prepare("
        SELECT 
            s.id as supplier_id,
            s.name as supplier_name,
            COUNT(DISTINCT ir.product_id) as product_count,
            SUM(ir.quantity) as total_quantity,
            SUM(ir.quantity * ir.price) as total_cost,
            ROUND(AVG(ir.price), 2) as avg_price
        FROM inventory_records ir
        JOIN products p ON ir.product_id = p.id
        JOIN suppliers s ON ir.supplier_id = s.id
        WHERE ir.type = 1
        AND ir.create_time BETWEEN ? AND ?
        $category_filter
        GROUP BY s.id, s.name
        ORDER BY total_cost DESC
    ");
    $stmt->execute($params);
    $purchase_by_supplier = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取采购成本分析数据失败: ' . $e->getMessage();
}

// 采购成本分析（按产品分类统计）
$purchase_by_category = [];

try {
    $stmt = $pdo->prepare("
        SELECT 
            pc.id as category_id,
            pc.name as category_name,
            COUNT(DISTINCT p.id) as product_count,
            SUM(ir.quantity) as total_quantity,
            SUM(ir.quantity * ir.price) as total_cost,
            ROUND(AVG(ir.price), 2) as avg_price
        FROM inventory_records ir
        JOIN products p ON ir.product_id = p.id
        JOIN product_categories pc ON p.category_id = pc.id
        WHERE ir.type = 1
        AND ir.create_time BETWEEN ? AND ?
        GROUP BY pc.id, pc.name
        ORDER BY total_cost DESC
    ");
    $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $purchase_by_category = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取分类采购成本数据失败: ' . $e->getMessage();
}

// 准备图表数据
// 库存变动趋势图表数据
$trend_periods = [];
$in_quantities = [];
$out_quantities = [];

foreach ($inventory_trend as $item) {
    $trend_periods[] = $item['period'];
    $in_quantities[] = $item['in_quantity'];
    $out_quantities[] = $item['out_quantity'];
}

$trend_periods_json = json_encode($trend_periods);
$in_quantities_json = json_encode($in_quantities);
$out_quantities_json = json_encode($out_quantities);

// 采购成本（按供应商）图表数据
$supplier_names = [];
$supplier_costs = [];

foreach ($purchase_by_supplier as $item) {
    $supplier_names[] = $item['supplier_name'];
    $supplier_costs[] = $item['total_cost'];
}

$supplier_names_json = json_encode($supplier_names);
$supplier_costs_json = json_encode($supplier_costs);

// 采购成本（按分类）图表数据
$category_names = [];
$category_costs = [];

foreach ($purchase_by_category as $item) {
    $category_names[] = $item['category_name'];
    $category_costs[] = $item['total_cost'];
}

$category_names_json = json_encode($category_names);
$category_costs_json = json_encode($category_costs);
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>库存数据分析 - FloraEase花店管理系统</title>
    <link rel="stylesheet" href="../style.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>库存数据分析</h2>
            <div class="breadcrumb">
                <a href="index.php">数据统计与分析</a> / 库存数据
            </div>
        </div>

        <div class="content">
            <?php if (!empty($error_message)): ?>
                <div class="alert alert-danger">
                    <?php echo $error_message; ?>
                </div>
            <?php endif; ?>

            <!-- 日期筛选 -->
            <div class="filter-form">
                <form method="get" action="inventory.php">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="date_range">时间范围</label>
                            <select id="date_range" name="date_range" onchange="toggleCustomDateFields()">
                                <option value="today" <?php echo $date_range == 'today' ? 'selected' : ''; ?>>今日</option>
                                <option value="yesterday" <?php echo $date_range == 'yesterday' ? 'selected' : ''; ?>>昨日</option>
                                <option value="week" <?php echo $date_range == 'week' ? 'selected' : ''; ?>>近7天</option>
                                <option value="month" <?php echo $date_range == 'month' ? 'selected' : ''; ?>>近30天</option>
                                <option value="quarter" <?php echo $date_range == 'quarter' ? 'selected' : ''; ?>>近90天</option>
                                <option value="year" <?php echo $date_range == 'year' ? 'selected' : ''; ?>>近一年</option>
                                <option value="custom" <?php echo $date_range == 'custom' ? 'selected' : ''; ?>>自定义</option>
                            </select>
                        </div>
                        <div class="filter-item custom-date" style="display: <?php echo $date_range == 'custom' ? 'block' : 'none'; ?>;">
                            <label for="custom_start">开始日期</label>
                            <input type="date" id="custom_start" name="custom_start" value="<?php echo $custom_start; ?>">
                        </div>
                        <div class="filter-item custom-date" style="display: <?php echo $date_range == 'custom' ? 'block' : 'none'; ?>;">
                            <label for="custom_end">结束日期</label>
                            <input type="date" id="custom_end" name="custom_end" value="<?php echo $custom_end; ?>">
                        </div>
                        <div class="filter-item">
                            <label for="category_id">产品分类</label>
                            <select id="category_id" name="category_id">
                                <option value="0">全部分类</option>
                                <?php foreach ($categories as $category): ?>
                                    <option value="<?php echo $category['id']; ?>" <?php echo $category_id == $category['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($category['category_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="period_type">趋势周期</label>
                            <select id="period_type" name="period_type">
                                <option value="day" <?php echo $period_type == 'day' ? 'selected' : ''; ?>>按日</option>
                                <option value="week" <?php echo $period_type == 'week' ? 'selected' : ''; ?>>按周</option>
                                <option value="month" <?php echo $period_type == 'month' ? 'selected' : ''; ?>>按月</option>
                            </select>
                        </div>
                    </div>
                    <div class="filter-buttons">
                        <button type="submit" class="btn btn-primary">查询</button>
                        <a href="inventory.php" class="btn btn-secondary">重置</a>
                    </div>
                </form>
            </div>

            <!-- 库存概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>总产品数</h3>
                    <div class="number"><?php echo number_format($inventory_overview['total_products']); ?></div>
                    <div class="desc">低库存产品: <?php echo number_format($inventory_overview['low_stock']); ?></div>
                </div>
                <div class="dashboard-card">
                    <h3>总库存量</h3>
                    <div class="number"><?php echo number_format($inventory_overview['total_inventory']); ?></div>
                    <div class="desc">统计范围: <?php echo $start_date; ?> 至 <?php echo $end_date; ?></div>
                </div>
                <div class="dashboard-card">
                    <h3>总库存价值</h3>
                    <div class="number">￥<?php echo number_format($inventory_overview['total_value'], 2); ?></div>
                    <div class="desc">按成本价计算</div>
                </div>
            </div>

            <!-- 库存变动趋势 -->
            <div class="section">
                <h2>库存变动趋势</h2>
                <div class="chart-container" style="position: relative; height:300px;">
                    <canvas id="inventoryTrendChart"></canvas>
                </div>
            </div>

            <!-- 库存周转率分析 -->
            <div class="section">
                <h2>库存周转率分析</h2>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>产品名称</th>
                                <th>产品编码</th>
                                <th>产品分类</th>
                                <th>当前库存</th>
                                <th>销售数量</th>
                                <th>周转率</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($turnover_rate)): ?>
                                <?php foreach ($turnover_rate as $item): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($item['product_name']); ?></td>
                                        <td><?php echo htmlspecialchars($item['product_code']); ?></td>
                                        <td><?php echo htmlspecialchars($item['category_name']); ?></td>
                                        <td><?php echo number_format($item['current_stock']); ?></td>
                                        <td><?php echo number_format($item['sold_quantity']); ?></td>
                                        <td><?php echo $item['turnover_rate']; ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
                <div class="section-note">
                    <p>注：库存周转率 = 销售数量 / 当前库存，数值越高表示周转越快</p>
                </div>
            </div>

            <!-- 采购成本分析（按供应商） -->
            <div class="section">
                <h2>采购成本分析（按供应商）</h2>
                <div class="row">
                    <div class="chart-container" style="position: relative; height:300px; width:50%; float:left;">
                        <canvas id="supplierCostChart"></canvas>
                    </div>
                    <div class="table-container" style="width:50%; float:left;">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>供应商</th>
                                    <th>产品数量</th>
                                    <th>采购总量</th>
                                    <th>采购成本</th>
                                    <th>平均单价</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (!empty($purchase_by_supplier)): ?>
                                    <?php foreach ($purchase_by_supplier as $item): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($item['supplier_name']); ?></td>
                                            <td><?php echo number_format($item['product_count']); ?></td>
                                            <td><?php echo number_format($item['total_quantity']); ?></td>
                                            <td>￥<?php echo number_format($item['total_cost'], 2); ?></td>
                                            <td>￥<?php echo number_format($item['avg_price'], 2); ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="5" class="text-center">暂无数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                    <div style="clear:both;"></div>
                </div>
            </div>

            <!-- 采购成本分析（按分类） -->
            <div class="section">
                <h2>采购成本分析（按分类）</h2>
                <div class="row">
                    <div class="chart-container" style="position: relative; height:300px; width:50%; float:left;">
                        <canvas id="categoryCostChart"></canvas>
                    </div>
                    <div class="table-container" style="width:50%; float:left;">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>产品分类</th>
                                    <th>产品数量</th>
                                    <th>采购总量</th>
                                    <th>采购成本</th>
                                    <th>平均单价</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (!empty($purchase_by_category)): ?>
                                    <?php foreach ($purchase_by_category as $item): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($item['category_name']); ?></td>
                                            <td><?php echo number_format($item['product_count']); ?></td>
                                            <td><?php echo number_format($item['total_quantity']); ?></td>
                                            <td>￥<?php echo number_format($item['total_cost'], 2); ?></td>
                                            <td>￥<?php echo number_format($item['avg_price'], 2); ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="5" class="text-center">暂无数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                    <div style="clear:both;"></div>
                </div>
            </div>

        </div>
    </div>

    <script>
        // 控制自定义日期字段的显示与隐藏
        function toggleCustomDateFields() {
            var dateRange = document.getElementById('date_range').value;
            var customDateFields = document.querySelectorAll('.custom-date');

            for (var i = 0; i < customDateFields.length; i++) {
                customDateFields[i].style.display = dateRange === 'custom' ? 'block' : 'none';
            }
        }

        // 绘制库存变动趋势图
        var ctx1 = document.getElementById('inventoryTrendChart').getContext('2d');
        var inventoryTrendChart = new Chart(ctx1, {
            type: 'line',
            data: {
                labels: <?php echo $trend_periods_json; ?>,
                datasets: [{
                    label: '入库数量',
                    data: <?php echo $in_quantities_json; ?>,
                    backgroundColor: 'rgba(75, 192, 192, 0.2)',
                    borderColor: 'rgba(75, 192, 192, 1)',
                    borderWidth: 1,
                    tension: 0.4
                }, {
                    label: '出库数量',
                    data: <?php echo $out_quantities_json; ?>,
                    backgroundColor: 'rgba(255, 99, 132, 0.2)',
                    borderColor: 'rgba(255, 99, 132, 1)',
                    borderWidth: 1,
                    tension: 0.4
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '数量'
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '时间'
                        }
                    }
                },
                plugins: {
                    title: {
                        display: true,
                        text: '库存变动趋势'
                    }
                }
            }
        });

        // 绘制采购成本（按供应商）图表
        var ctx2 = document.getElementById('supplierCostChart').getContext('2d');
        var supplierCostChart = new Chart(ctx2, {
            type: 'bar',
            data: {
                labels: <?php echo $supplier_names_json; ?>,
                datasets: [{
                    label: '采购成本(元)',
                    data: <?php echo $supplier_costs_json; ?>,
                    backgroundColor: 'rgba(54, 162, 235, 0.7)',
                    borderColor: 'rgba(54, 162, 235, 1)',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '采购成本(元)'
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '供应商'
                        }
                    }
                },
                plugins: {
                    title: {
                        display: true,
                        text: '供应商采购成本分布'
                    }
                }
            }
        });

        // 绘制采购成本（按分类）图表
        var ctx3 = document.getElementById('categoryCostChart').getContext('2d');
        var categoryCostChart = new Chart(ctx3, {
            type: 'pie',
            data: {
                labels: <?php echo $category_names_json; ?>,
                datasets: [{
                    data: <?php echo $category_costs_json; ?>,
                    backgroundColor: [
                        'rgba(255, 99, 132, 0.7)',
                        'rgba(54, 162, 235, 0.7)',
                        'rgba(255, 206, 86, 0.7)',
                        'rgba(75, 192, 192, 0.7)',
                        'rgba(153, 102, 255, 0.7)',
                        'rgba(255, 159, 64, 0.7)',
                        'rgba(201, 203, 207, 0.7)',
                        'rgba(255, 99, 71, 0.7)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        position: 'right'
                    },
                    title: {
                        display: true,
                        text: '分类采购成本分布'
                    }
                }
            }
        });
    </script>
</body>

</html>