<?php
// store/info.php - 门店信息管理
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('store.view');

// 处理操作请求
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$message = '';
$messageType = '';

// 处理门店添加
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'add') {
    // 检查添加权限
    check_permission_or_die('store.add');

    $name = $_POST['name'] ?? '';
    $area = $_POST['area'] ?? '';
    $address = $_POST['address'] ?? '';
    $contact_person = $_POST['contact_person'] ?? '';
    $phone = $_POST['phone'] ?? '';
    $business_hours = $_POST['business_hours'] ?? '';
    $status = isset($_POST['status']) ? 1 : 0;

    if (empty($name) || empty($area) || empty($address) || empty($contact_person) || empty($phone) || empty($business_hours)) {
        $message = '请填写所有必填字段';
        $messageType = 'danger';
    } else {
        try {
            $stmt = $pdo->prepare("INSERT INTO stores (name, area, address, contact_person, phone, business_hours, status) VALUES (?, ?, ?, ?, ?, ?, ?)");
            $stmt->execute([$name, $area, $address, $contact_person, $phone, $business_hours, $status]);

            record_log("添加门店: $name");
            $message = '门店添加成功';
            $messageType = 'success';
            $action = 'list'; // 返回列表视图
        } catch (PDOException $e) {
            $message = '门店添加失败: ' . $e->getMessage();
            $messageType = 'danger';
        }
    }
}

// 处理门店更新
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'edit') {
    // 检查编辑权限
    check_permission_or_die('store.edit');

    $id = $_POST['id'] ?? 0;
    $name = $_POST['name'] ?? '';
    $area = $_POST['area'] ?? '';
    $address = $_POST['address'] ?? '';
    $contact_person = $_POST['contact_person'] ?? '';
    $phone = $_POST['phone'] ?? '';
    $business_hours = $_POST['business_hours'] ?? '';
    $status = isset($_POST['status']) ? 1 : 0;

    if (empty($id) || empty($name) || empty($area) || empty($address) || empty($contact_person) || empty($phone) || empty($business_hours)) {
        $message = '请填写所有必填字段';
        $messageType = 'danger';
    } else {
        try {
            $stmt = $pdo->prepare("UPDATE stores SET name = ?, area = ?, address = ?, contact_person = ?, phone = ?, business_hours = ?, status = ? WHERE id = ?");
            $stmt->execute([$name, $area, $address, $contact_person, $phone, $business_hours, $status, $id]);

            record_log("更新门店: $name (ID: $id)");
            $message = '门店更新成功';
            $messageType = 'success';
            $action = 'list'; // 返回列表视图
        } catch (PDOException $e) {
            $message = '门店更新失败: ' . $e->getMessage();
            $messageType = 'danger';
        }
    }
}

// 处理门店删除
if ($action === 'delete' && isset($_GET['id'])) {
    // 检查删除权限
    check_permission_or_die('store.delete');

    $id = $_GET['id'];

    try {
        // 检查该门店是否有关联的员工
        $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM employees WHERE store_id = ?");
        $stmt->execute([$id]);
        $employeeCount = $stmt->fetch()['count'];

        if ($employeeCount > 0) {
            $message = '无法删除：该门店下有' . $employeeCount . '名员工';
            $messageType = 'danger';
        } else {
            $stmt = $pdo->prepare("DELETE FROM stores WHERE id = ?");
            $stmt->execute([$id]);

            record_log("删除门店 (ID: $id)");
            $message = '门店删除成功';
            $messageType = 'success';
        }
    } catch (PDOException $e) {
        $message = '门店删除失败: ' . $e->getMessage();
        $messageType = 'danger';
    }
    $action = 'list'; // 返回列表视图
}

// 获取单个门店信息（用于编辑和查看）
$storeInfo = null;
if (($action === 'edit' || $action === 'view') && isset($_GET['id'])) {
    $id = $_GET['id'];
    try {
        $stmt = $pdo->prepare("SELECT * FROM stores WHERE id = ?");
        $stmt->execute([$id]);
        $storeInfo = $stmt->fetch();

        if (!$storeInfo) {
            $message = '门店不存在';
            $messageType = 'danger';
            $action = 'list'; // 返回列表视图
        }
    } catch (PDOException $e) {
        $message = '获取门店信息失败: ' . $e->getMessage();
        $messageType = 'danger';
        $action = 'list'; // 返回列表视图
    }
}

// 获取门店列表（用于列表视图）
$stores = [];
if ($action === 'list') {
    // 分页参数
    $page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
    $limit = 10;
    $offset = ($page - 1) * $limit;

    // 搜索条件
    $searchName = isset($_GET['search_name']) ? $_GET['search_name'] : '';
    $searchArea = isset($_GET['search_area']) ? $_GET['search_area'] : '';
    $searchStatus = isset($_GET['search_status']) ? $_GET['search_status'] : '';

    $where = [];
    $params = [];

    if (!empty($searchName)) {
        $where[] = "name LIKE ?";
        $params[] = "%$searchName%";
    }

    if (!empty($searchArea)) {
        $where[] = "area LIKE ?";
        $params[] = "%$searchArea%";
    }

    if ($searchStatus !== '') {
        $where[] = "status = ?";
        $params[] = $searchStatus;
    }

    $whereClause = empty($where) ? "" : "WHERE " . implode(" AND ", $where);

    // 获取总记录数
    $countSql = "SELECT COUNT(*) as total FROM stores $whereClause";
    $stmt = $pdo->prepare($countSql);
    $stmt->execute($params);
    $totalRecords = $stmt->fetch()['total'];
    $totalPages = ceil($totalRecords / $limit);

    // 获取分页数据
    $sql = "SELECT * FROM stores $whereClause ORDER BY id DESC LIMIT $offset, $limit";
    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $stores = $stmt->fetchAll();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>门店信息管理 - FloraEase</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>门店信息管理</h2>
            <div class="breadcrumb">
                <a href="index.php">门店管理</a> / 门店信息
            </div>
        </div>

        <div class="content">
            <?php if (!empty($message)): ?>
                <div class="alert alert-<?php echo $messageType; ?>">
                    <?php echo $message; ?>
                </div>
            <?php endif; ?>

            <?php if ($action === 'list'): ?>
                <!-- 操作栏 -->
                <div class="action-bar">
                    <?php if (has_permission('store.add')): ?>
                        <a href="?action=add" class="btn btn-primary">添加门店</a>
                    <?php endif; ?>
                </div>

                <!-- 搜索表单 -->
                <form method="get" action="info.php" class="filter-form">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="search_name">门店名称</label>
                            <input type="text" id="search_name" name="search_name" value="<?php echo htmlspecialchars($searchName ?? ''); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="search_area">所属区域</label>
                            <input type="text" id="search_area" name="search_area" value="<?php echo htmlspecialchars($searchArea ?? ''); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="search_status">状态</label>
                            <select id="search_status" name="search_status">
                                <option value="">全部</option>
                                <option value="1" <?php echo $searchStatus === '1' ? 'selected' : ''; ?>>营业中</option>
                                <option value="0" <?php echo $searchStatus === '0' ? 'selected' : ''; ?>>已关闭</option>
                            </select>
                        </div>
                    </div>
                    <div class="filter-buttons">
                        <button type="submit" class="btn btn-primary">搜索</button>
                        <a href="?action=list" class="btn btn-secondary">重置</a>
                    </div>
                </form>

                <!-- 门店列表 -->
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>门店名称</th>
                                <th>所属区域</th>
                                <th>联系人</th>
                                <th>电话</th>
                                <th>营业时间</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($stores as $store): ?>
                                <tr>
                                    <td><?php echo $store['id']; ?></td>
                                    <td><?php echo htmlspecialchars($store['name']); ?></td>
                                    <td><?php echo htmlspecialchars($store['area']); ?></td>
                                    <td><?php echo htmlspecialchars($store['contact_person']); ?></td>
                                    <td><?php echo htmlspecialchars($store['phone']); ?></td>
                                    <td><?php echo htmlspecialchars($store['business_hours']); ?></td>
                                    <td>
                                        <?php if ($store['status'] == 1): ?>
                                            <span class="status-active">营业中</span>
                                        <?php else: ?>
                                            <span class="status-inactive">已关闭</span>
                                        <?php endif; ?>
                                    </td>
                                    <td><?php echo $store['create_time']; ?></td>
                                    <td>
                                        <a href="?action=view&id=<?php echo $store['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                        <?php if (has_permission('store.edit')): ?>
                                            <a href="?action=edit&id=<?php echo $store['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                        <?php endif; ?>
                                        <?php if (has_permission('store.delete')): ?>
                                            <a href="?action=delete&id=<?php echo $store['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此门店吗？')">删除</a>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                            <?php if (empty($stores)): ?>
                                <tr>
                                    <td colspan="9" class="text-center">暂无门店数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 分页 -->
                <?php if ($totalPages > 1): ?>
                    <div class="pagination">
                        <?php if ($page > 1): ?>
                            <a href="?action=list&page=1<?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchArea) ? '&search_area=' . urlencode($searchArea) : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">首页</a>
                            <a href="?action=list&page=<?php echo $page - 1; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchArea) ? '&search_area=' . urlencode($searchArea) : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">上一页</a>
                        <?php endif; ?>

                        <?php
                        $startPage = max(1, $page - 2);
                        $endPage = min($totalPages, $page + 2);

                        for ($i = $startPage; $i <= $endPage; $i++):
                        ?>
                            <a href="?action=list&page=<?php echo $i; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchArea) ? '&search_area=' . urlencode($searchArea) : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>"><?php echo $i; ?></a>
                        <?php endfor; ?>

                        <?php if ($page < $totalPages): ?>
                            <a href="?action=list&page=<?php echo $page + 1; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchArea) ? '&search_area=' . urlencode($searchArea) : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">下一页</a>
                            <a href="?action=list&page=<?php echo $totalPages; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchArea) ? '&search_area=' . urlencode($searchArea) : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">末页</a>
                        <?php endif; ?>
                    </div>
                    <div class="pagination-info">
                        共 <?php echo $totalRecords; ?> 条记录，当前 <?php echo $page; ?>/<?php echo $totalPages; ?> 页
                    </div>
                <?php endif; ?>

            <?php elseif ($action === 'add' || $action === 'edit'): ?>
                <!-- 添加/编辑门店表单 -->
                <form method="post" action="?action=<?php echo $action; ?>" class="form-container">
                    <h3><?php echo $action === 'add' ? '添加门店' : '编辑门店'; ?></h3>

                    <?php if ($action === 'edit'): ?>
                        <input type="hidden" name="id" value="<?php echo $storeInfo['id']; ?>">
                    <?php endif; ?>

                    <div class="form-group">
                        <label for="name">门店名称 *</label>
                        <input type="text" id="name" name="name" value="<?php echo $action === 'edit' ? htmlspecialchars($storeInfo['name']) : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="area">所属区域 *</label>
                        <input type="text" id="area" name="area" value="<?php echo $action === 'edit' ? htmlspecialchars($storeInfo['area']) : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="address">门店地址 *</label>
                        <input type="text" id="address" name="address" value="<?php echo $action === 'edit' ? htmlspecialchars($storeInfo['address']) : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="contact_person">联系人 *</label>
                        <input type="text" id="contact_person" name="contact_person" value="<?php echo $action === 'edit' ? htmlspecialchars($storeInfo['contact_person']) : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="phone">联系电话 *</label>
                        <input type="text" id="phone" name="phone" value="<?php echo $action === 'edit' ? htmlspecialchars($storeInfo['phone']) : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="business_hours">营业时间 *</label>
                        <input type="text" id="business_hours" name="business_hours" value="<?php echo $action === 'edit' ? htmlspecialchars($storeInfo['business_hours']) : ''; ?>" required placeholder="例如: 09:00-21:00">
                    </div>

                    <div class="form-group">
                        <label for="status">状态</label>
                        <div class="checkbox-item">
                            <label>
                                <input type="checkbox" id="status" name="status" value="1" <?php echo $action === 'edit' && $storeInfo['status'] == 1 ? 'checked' : ''; ?>> 营业中
                            </label>
                        </div>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary"><?php echo $action === 'add' ? '添加' : '保存'; ?></button>
                        <a href="?action=list" class="btn btn-secondary">取消</a>
                    </div>
                </form>

            <?php elseif ($action === 'view'): ?>
                <!-- 门店详情 -->
                <div class="form-container">
                    <h3>门店详情</h3>

                    <table class="info-table">
                        <tr>
                            <td width="20%">门店ID：</td>
                            <td><?php echo $storeInfo['id']; ?></td>
                        </tr>
                        <tr>
                            <td>门店名称：</td>
                            <td><?php echo htmlspecialchars($storeInfo['name']); ?></td>
                        </tr>
                        <tr>
                            <td>所属区域：</td>
                            <td><?php echo htmlspecialchars($storeInfo['area']); ?></td>
                        </tr>
                        <tr>
                            <td>门店地址：</td>
                            <td><?php echo htmlspecialchars($storeInfo['address']); ?></td>
                        </tr>
                        <tr>
                            <td>联系人：</td>
                            <td><?php echo htmlspecialchars($storeInfo['contact_person']); ?></td>
                        </tr>
                        <tr>
                            <td>联系电话：</td>
                            <td><?php echo htmlspecialchars($storeInfo['phone']); ?></td>
                        </tr>
                        <tr>
                            <td>营业时间：</td>
                            <td><?php echo htmlspecialchars($storeInfo['business_hours']); ?></td>
                        </tr>
                        <tr>
                            <td>状态：</td>
                            <td><?php echo $storeInfo['status'] == 1 ? '<span class="status-active">营业中</span>' : '<span class="status-inactive">已关闭</span>'; ?></td>
                        </tr>
                        <tr>
                            <td>创建时间：</td>
                            <td><?php echo $storeInfo['create_time']; ?></td>
                        </tr>
                    </table>

                    <div class="form-actions">
                        <?php if (has_permission('store.edit')): ?>
                            <a href="?action=edit&id=<?php echo $storeInfo['id']; ?>" class="btn btn-primary">编辑</a>
                        <?php endif; ?>
                        <a href="?action=list" class="btn btn-secondary">返回</a>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>